@@ -6,7 +6,6 @@ use kwap_msg::{Opt, OptNumber};
 #[cfg(feature = "alloc")]
 use std_alloc::vec::Vec;
 
-use crate::core::event::Event;
 use crate::socket::Socket;
 
 /// Used to associate a value with a RetryTimer.
@@ -56,7 +55,6 @@ impl<Clk: Clock<T = u64> + 'static, Sock: Socket + 'static> Config for Alloc<Clk
   type OptBytes = Vec<u8>;
   type Opts = Vec<Opt<Vec<u8>>>;
   type OptMap = Vec<(OptNumber, Opt<Vec<u8>>)>;
-  type Events = Vec<Event<Self>>;
   type Clock = Clk;
   type Socket = Sock;
 }
@@ -87,9 +85,6 @@ pub trait Config: Sized + 'static + core::fmt::Debug {
   /// What type should we use to keep track of options before serializing?
   type OptMap: Array<Item = (OptNumber, Opt<Self::OptBytes>)> + Clone + Debug;
 
-  /// What type should we use to store events?
-  type Events: Array<Item = Event<Self>>;
-
   /// What should we use to keep track of time?
   type Clock: Clock<T = u64>;
 
